@@ -15,34 +15,32 @@
  *  along with this program; if not, write to the Free Software
  */
 
-#include <QPainter>
+#include <QtGui/QPainter>
+#include <QtGui/qdrawutil.h>
+#include <QtGui/QCursor>
+#include <QtGui/QImage>
+#include <QtGui/QMouseEvent>
+#include <QtCore/QTimerEvent>
+#include <QtGui/QResizeEvent>
+#include <QtCore/QProcess>
+#include <QtGui/QX11Info>
 
-#include <qdrawutil.h>
-#include <QCursor>
-#include <QImage>
 #include <KMenu>
-//Added by qt3to4:
-#include <QMouseEvent>
-#include <QTimerEvent>
-#include <QResizeEvent>
-
 #include <kaboutapplicationdialog.h>
-#include <kmenu.h>
 #include <kaboutdata.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
+#include <kcolorscheme.h>
 #include <kapplication.h>
 #include <kiconloader.h>
 #include <kiconeffect.h>
 #include <kshortcut.h>
 #include <kdemacros.h>
 #include <ktoolinvocation.h>
-#include <QProcess>
 #include "kdeexportfix.h"
 #include "kbstate.h"
 #include "kbstate.moc"
-#include <QX11Info>
 
 extern "C"
 {
@@ -791,17 +789,17 @@ void KeyIcon::resizeEvent( QResizeEvent*e )
 void KeyIcon::updateImages () {
    int size = width()<height() ? width() : height();
 
-   locked    = iconLoader->loadIcon("lock_overlay", K3Icon::Panel, size-4);
+   locked    = iconLoader->loadIcon("lock_overlay", KIconLoader::Panel, size-4);
 	if (strcmp(modifierKeys[keyId].icon, "")) {
-	   latched   = iconLoader->loadIcon(modifierKeys[keyId].icon, K3Icon::NoGroup, size-4);
-   	unlatched = iconLoader->loadIcon(modifierKeys[keyId].icon, K3Icon::NoGroup, size-4);
+	   latched   = iconLoader->loadIcon(modifierKeys[keyId].icon, KIconLoader::NoGroup, size-4);
+   	unlatched = iconLoader->loadIcon(modifierKeys[keyId].icon, KIconLoader::NoGroup, size-4);
 		
 		QImage img = latched.convertToImage();
-		KIconEffect::colorize(img,  KGlobalSettings::highlightedTextColor(), 1.0);
+		KIconEffect::colorize(img,  KColorScheme(QPalette::Active, KColorScheme::Selection).foreground().color(), 1.0);
 		latched.convertFromImage (img);
 		
 		img = unlatched.convertToImage();
-		KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+		KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
 		unlatched.convertFromImage (img);
 	}
 
@@ -816,17 +814,17 @@ void KeyIcon::drawButton (QPainter *p) {
    int o = 0;
    if (isLocked || isLatched) {
       qDrawShadePanel (p, 0, 0, width(), height(), colorGroup(), true, 1, NULL);
-      p->fillRect (1,1,width()-2,height()-2, KGlobalSettings::highlightColor());
+      p->fillRect (1,1,width()-2,height()-2, KColorScheme(QPalette::Active, KColorScheme::Selection).background().color());
 		if (strcmp(modifierKeys[keyId].icon, ""))
 			p->drawPixmap (x+1,y+1, latched);
-      black = KGlobalSettings::highlightedTextColor();
+      black = KColorScheme(QPalette::Active, KColorScheme::Selection).foreground().color();
       o = 1;
    }
    else {
       qDrawShadePanel (p, 0, 0, width(), height(), colorGroup(), false, 1, NULL);
 		if (strcmp(modifierKeys[keyId].icon, ""))
 			p->drawPixmap (x,y, unlatched);
-      black = KGlobalSettings::textColor();
+      black = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
    }
 
    QString text = i18n(modifierKeys[keyId].text);
@@ -892,7 +890,7 @@ void MouseIcon::resizeEvent( QResizeEvent*e )
 }
 
 QPixmap loadIcon(KIconLoader *iconLoader, int size, const QColor &color, const QString &name) {
-	QPixmap result = iconLoader->loadIcon(name, K3Icon::NoGroup, size);
+	QPixmap result = iconLoader->loadIcon(name, KIconLoader::NoGroup, size);
 
 	QImage img = result.convertToImage();
 	KIconEffect::colorize(img, color, 1.0);
@@ -904,8 +902,8 @@ QPixmap loadIcon(KIconLoader *iconLoader, int size, const QColor &color, const Q
 void MouseIcon::updateImages () {
 	int size = width()<height() ? width() : height();
 
-	QColor textcolor = KGlobalSettings::textColor();
-	QColor basecolor = KGlobalSettings::baseColor();
+	QColor textcolor = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+	QColor basecolor = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
 	mouse = loadIcon (iconLoader, size, textcolor, "kbstate_mouse");
 	leftSelected   = loadIcon (iconLoader, size, textcolor,
 										"kbstate_mouse_left_selected");
@@ -977,10 +975,10 @@ TimeoutIcon::~TimeoutIcon () {
 void TimeoutIcon::update () {
    int size = width()<height() ? width() : height();
    if (pixmap.width() != size)
-		pixmap = iconLoader->loadIcon(iconname, K3Icon::NoGroup, size);
+		pixmap = iconLoader->loadIcon(iconname, KIconLoader::NoGroup, size);
 
    QImage img = pixmap.convertToImage();
-   KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+   KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
    pixmap.convertFromImage (img);
 
    image = pixmap;
@@ -992,7 +990,7 @@ void TimeoutIcon::setGlyth (const QString &glyth) {
    this->glyth = glyth;
 
    QImage img = pixmap.convertToImage();
-   KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+   KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
    pixmap.convertFromImage (img);
 
    image = pixmap;
@@ -1004,10 +1002,10 @@ void TimeoutIcon::setImage (const QString &name, int timeout) {
    iconname = name;
 	if (!name.isNull() && !name.isEmpty()) {
 	   int size = width()<height() ? width() : height();
-		pixmap = iconLoader->loadIcon(iconname, K3Icon::NoGroup, size);
+		pixmap = iconLoader->loadIcon(iconname, KIconLoader::NoGroup, size);
 
    	QImage img = pixmap.convertToImage();
-   	KIconEffect::colorize(img, KGlobalSettings::textColor(), 1.0);
+   	KIconEffect::colorize(img, KColorScheme(QPalette::Active, KColorScheme::View).foreground().color(), 1.0);
    	pixmap.convertFromImage (img);
 
    	image = pixmap;
@@ -1049,12 +1047,12 @@ void TimeoutIcon::drawButton (QPainter *p) {
 
    p->setFont (font);
 	if (count == 1) {
-		p->setPen (KGlobalSettings::textColor());
+		p->setPen (KColorScheme(QPalette::Active, KColorScheme::View).foreground().color());
 	   p->drawText (0,0, width()/2, height()/2, Qt::AlignCenter, text);
 	}
 	else {
-		QColor t = KGlobalSettings::textColor();
-		QColor b = KGlobalSettings::baseColor();
+		QColor t = KColorScheme(QPalette::Active, KColorScheme::View).foreground().color();
+		QColor b = KColorScheme(QPalette::Active, KColorScheme::View).background().color();
 		p->setPen (QColor ((2*t.red()+3*b.red())/5,
 					  (2*t.green()+3*b.green())/5,
 					  (2*t.blue()+3*b.blue())/5));
@@ -1063,7 +1061,7 @@ void TimeoutIcon::drawButton (QPainter *p) {
 					  (2*t.green()+b.green())/3,
 					  (2*t.blue()+b.blue())/3));
 		p->drawText (0,0, width(), height(), Qt::AlignCenter, text);
-		p->setPen (KGlobalSettings::textColor());
+		p->setPen (KColorScheme(QPalette::Active, KColorScheme::View).foreground().color());
 		p->drawText (0,0, width()/2, height(), Qt::AlignCenter, text);
 	}
 }
