@@ -22,16 +22,16 @@
  ******************************************************************************/
 
 // Qt includes.
-#include <QRegExp>
-#include <qdom.h>
-#include <QApplication>
-//Added by qt3to4:
-#include <QCustomEvent>
+#include <QtCore/QRegExp>
+#include <QtXml/qdom.h>
+#include <QtGui/QApplication>
+#include <QtCore/QCustomEvent>
 
 // KDE includes.
 #include <kdebug.h>
 #include <klocale.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 
 // KTTS includes.
 #include "utils.h"
@@ -367,7 +367,7 @@ QString SbdThread::parseSsmlNode( QDomNode& n, const QString& re )
             {
                 result += startSentence();
                 result += makeSentence( sentenceList[lastNdx] );
-                if ( s.endsWith( "\t" ) ) result += endSentence();
+                if ( s.endsWith( '\t' ) ) result += endSentence();
             }
             break; }
         case QDomNode::CDATASectionNode: {          // = 4
@@ -385,7 +385,7 @@ QString SbdThread::parseSsmlNode( QDomNode& n, const QString& re )
             {
                 result += startSentence();
                 result += makeSentence( makeCDATA( sentenceList[lastNdx] ) );
-                if ( s.endsWith( "\t" ) ) result += endSentence();
+                if ( s.endsWith( '\t' ) ) result += endSentence();
             }
             break; }
         case QDomNode::EntityReferenceNode: {       // = 5
