@@ -24,24 +24,23 @@
 #include <math.h>
 
 // Qt includes.
-#include <QWidget>
-#include <QTabWidget>
-#include <QCheckBox>
-#include <QLayout>
-#include <QRadioButton>
-#include <QSlider>
-#include <QLabel>
-#include <QTreeWidget>
-#include <QHeaderView>
-#include <QTextStream>
-#include <QMenu>
+#include <QtGui/QWidget>
+#include <QtGui/QTabWidget>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLayout>
+#include <QtGui/QRadioButton>
+#include <QtGui/QSlider>
+#include <QtGui/QLabel>
+#include <QtGui/QTreeWidget>
+#include <QtGui/QHeaderView>
+#include <QtCore/QTextStream>
+#include <QtGui/QMenu>
 
 // KDE includes.
 #include <kparts/componentfactory.h>
 #include <klineedit.h>
 #include <kurlrequester.h>
 #include <kicon.h>
-#include <kgenericfactory.h>
 #include <kstandarddirs.h>
 #include <kaboutdata.h>
 #include <kconfig.h>
@@ -53,6 +52,9 @@
 #include <ktoolinvocation.h>
 #include <kdialog.h>
 #include <kspeech.h>
+#include <kpluginfactory.h>
+#include <kpluginloader.h>
+
 
 // KTTS includes.
 #include "talkercode.h"
@@ -95,8 +97,9 @@ const int timeBoxValue = 100;
 const bool keepAudioCheckBoxValue = false;
 
 // Make this a plug in.
-typedef KGenericFactory<KCMKttsMgr, QWidget> KCMKttsMgrFactory;
-K_EXPORT_COMPONENT_FACTORY( kttsd, KCMKttsMgrFactory("kttsd") )
+K_PLUGIN_FACTORY(KCMKttsMgrFactory, registerPlugin<KCMKttsMgr>();)
+K_EXPORT_PLUGIN(KCMKttsMgrFactory("kttsd"))
+
 
 // ----------------------------------------------------------------------------
 
@@ -280,7 +283,7 @@ QVariant SbdFilterListModel::headerData(int section, Qt::Orientation orientation
 /**
 * Constructor.
 */
-KCMKttsMgr::KCMKttsMgr(QWidget *parent, const QStringList &) :
+KCMKttsMgr::KCMKttsMgr(QWidget *parent, const QVariantList &) :
     KCModule(KCMKttsMgrFactory::componentData(), parent/*, name*/),
     m_kspeech(0)
 {
@@ -1522,7 +1525,7 @@ void KCMKttsMgr::slotRemoveTalkerButton_clicked(){
 
     updateTalkerButtons();
 
-    // Emit configuraton changed.
+    // Emit configuration changed.
     configChanged();
 }
 
@@ -1564,7 +1567,7 @@ void KCMKttsMgr::removeFilter( bool sbd )
     kDebug() << "KCMKttsMgr::removeFilter: removing FilterID = " << filterID << " from config file.";
     m_config->deleteGroup(QString("Filter_")+filterID, 0);
 
-    // Emit configuraton changed.
+    // Emit configuration changed.
     configChanged();
 }
 
